@@ -1,11 +1,11 @@
 #define NAME          "IPhreeqc"
 #define VER_MAJOR      3
-#define VER_MINOR      7
-#define VER_PATCH      6
-#define VER_REVISION   16703
-#define GIT_COMMIT     d77b07649cd5d5141ea5a43eb369af150d01e807
+#define VER_MINOR      8
+#define VER_PATCH      0
+#define VER_REVISION   16920
+#define GIT_COMMIT     e63b6356326c4c6f1c45f50c22254d3f5eaeb9c7
 
-#define RELEASE_DATE           "December  7, 2023"
+#define RELEASE_DATE           "July 11, 2024"
 
 #define APR_STRINGIFY(n) APR_STRINGIFY_HELPER(n)
 #define APR_STRINGIFY_HELPER(n) #n
