@@ -1,5 +1,13 @@
 #include "SelectedOutput.h"
 
+#if defined(PHREEQCI_GUI)
+#ifdef _DEBUG
+#define new DEBUG_NEW
+#undef THIS_FILE
+static char THIS_FILE[] = __FILE__;
+#endif
+#endif
+
 SelectedOutput::SelectedOutput(int n, PHRQ_io *io)
 :	cxxNumKeyword(io)
 {
