@@ -49,6 +49,8 @@ class cxxSolution:public cxxNumKeyword
 	void Set_cb(LDBLE l_cb)                             {this->cb = l_cb;}
 	LDBLE Get_density() const                           {return this->density;}
 	void Set_density(LDBLE l_density)                   {this->density = l_density;}
+	LDBLE Get_viscosity() const                         { return this->viscosity; }
+	void Set_viscosity(LDBLE l_viscos)                  { this->viscosity = l_viscos; }
 	LDBLE Get_mass_water() const                        {return this->mass_water;}
 	void Set_mass_water(LDBLE l_mass_water)             {this->mass_water = l_mass_water;}
 	LDBLE Get_total_alkalinity() const                  {return this->total_alkalinity;}
@@ -131,6 +133,7 @@ class cxxSolution:public cxxNumKeyword
 	LDBLE cb;
 	LDBLE mass_water;
 	LDBLE density;
+	LDBLE viscosity;
 	LDBLE soln_vol;
 	LDBLE total_alkalinity;
 	cxxNameDouble totals;
