@@ -115,11 +115,7 @@ calc_kinetic_reaction(cxxKinetics *kinetics_ptr, LDBLE time_step)
 						kinetics_comp_ptr->Get_rate_name().c_str());
 				error_msg(error_string, STOP);
 			}
-#ifdef NPP
-			if (isnan(rate_moles))
-#else
-			if (rate_moles == NAN)
-#endif
+			if (std::isnan(rate_moles))
 			{
 				error_string = sformatf( "Moles of reaction not SAVEed for %s.",
 						kinetics_comp_ptr->Get_rate_name().c_str());
@@ -1583,7 +1579,10 @@ set_and_run(int i, int use_mix, int use_kinetics, int nsaver,
 		converge = model();
 	}
 	sum_species();
-	viscosity();
+	viscos = viscosity(NULL);
+	use.Get_solution_ptr()->Set_viscosity(viscos);
+	if (use.Get_surface_ptr() != NULL && dl_type_x != cxxSurface::NO_DL)
+		use.Get_surface_ptr()->Set_DDL_viscosity(viscosity(use.Get_surface_ptr()));
 	return (converge);
 }
 
