@@ -52,7 +52,8 @@ pitzer_tidy(void)
 	const char *string1, *string2;
 	int i, j, order;
 	int i0, i1, i2;
-	int count_pos, count_neg, count_neut, count[3], jj;
+	//int count_pos, count_neg, count_neut, count[3], jj;
+	int count_neut, count[3], jj;
 	LDBLE z0, z1;
 	class pitz_param *pzp_ptr;
 	class theta_param *theta_param_ptr;
@@ -339,12 +340,13 @@ pitzer_tidy(void)
 			i0 = pitz_params[i]->ispec[0];
 			i1 = pitz_params[i]->ispec[1];
 			i2 = pitz_params[i]->ispec[2];
-			count_pos = count_neg = count_neut = 0;
+			//count_pos = count_neg = count_neut = 0;
+			count_neut = 0;
 			for (j = 0; j <= 2; j++)
 			{
 				if (spec[pitz_params[i]->ispec[j]]->z > 0)
 				{
-					count_pos++;
+					//count_pos++;
 				}
 				if (spec[pitz_params[i]->ispec[j]]->z == 0)
 				{
@@ -352,7 +354,7 @@ pitzer_tidy(void)
 				}
 				if (spec[pitz_params[i]->ispec[j]]->z < 0)
 				{
-					count_neg++;
+					//count_neg++;
 				}
 			}
 			/* All neutral */
